@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DBINITIALIZERTEST_H
-#define DBINITIALIZERTEST_H
+#pragma once
 
 #include <QObject>
 class QIODevice;
@@ -23,4 +22,3 @@ private:
     static QString readNextStatement(QIODevice *io);
 };
 
-#endif
