@@ -24,7 +24,7 @@
 #include <QSessionManager>
 
 #include <KAboutData>
-#include <KCrash/KCrash>
+#include <KCrash>
 
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
@@ -70,9 +70,9 @@ int main(int argc, char **argv)
     AccountsIntegration accountsIntegration(agentManager);
 #endif
     KCrash::setEmergencySaveFunction(crashHandler);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-
+#endif
     // akonadi_control is started on-demand, no need to auto restart by session.
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
